@@ -245,6 +245,12 @@ ODOO_MSGS = {
         'translation-positional-used',
         settings.DESC_DFLT
     ),
+    'W%d21' % settings.BASE_NOMODULE_ID: (
+        'Context overridden using dict. '
+        'Better using kwargs `with_context(**%s)` or `with_context(key=value)`',
+        'context-overridden',
+        settings.DESC_DFLT
+    ),
     'F%d01' % settings.BASE_NOMODULE_ID: (
         'File "%s": "%s" not found.',
         'resource-not-exist',
@@ -431,6 +437,18 @@ class NoModuleChecker(misc.PylintOdooChecker):
         """
         return dict(item.split(":") for item in colon_list)
 
+    def _sqli_allowable(self, node):
+        # sql.SQL or sql.Identifier is OK
+        if self._is_psycopg2_sql(node):
+            return True
+        if isinstance(node, astroid.Call):
+            node = node.func
+        # self._thing is OK (mostly self._table), self._thing() also because
+        # it's a common pattern of reports (self._select, self._group_by, ...)
+        return (isinstance(node, astroid.Attribute)
+                and isinstance(node.expr, astroid.Name)
+                and node.attrname.startswith('_'))
+
     def _is_psycopg2_sql(self, node):
         if isinstance(node, astroid.Name):
             for assignation_node in self._get_assignation_nodes(node):
@@ -455,23 +473,63 @@ class NoModuleChecker(misc.PylintOdooChecker):
             return True
 
     def _check_node_for_sqli_risk(self, node):
-        is_bin_op = (isinstance(node, astroid.BinOp) and
-                     node.op in ('%', '+') and
-                     # ignore self._table / model._table / self._uid...
-                     not (isinstance(node.right, astroid.Attribute) and
-                          node.right.attrname.startswith('_')))
+        if isinstance(node, astroid.BinOp) and node.op in ('%', '+'):
+            if isinstance(node.right, astroid.Tuple):
+                # execute("..." % (self._table, thing))
+                if not all(map(self._sqli_allowable, node.right.elts)):
+                    return True
+            elif isinstance(node.right, astroid.Dict):
+                # execute("..." % {'table': self._table}
+                if not all(self._sqli_allowable(v) for _, v in node.right.items):
+                    return True
+            elif not self._sqli_allowable(node.right):
+                # execute("..." % self._table)
+                return True
 
-        is_format = (isinstance(node, astroid.Call) and
-                     self.get_func_name(node.func) == 'format')
-        if is_format:
-            # exclude sql.SQL or sql.Identifier
-            is_psycopg2 = (
-                list(map(self._is_psycopg2_sql, node.args)) +
-                [self._is_psycopg2_sql(keyword.value)
-                 for keyword in (node.keywords or [])])
-            if is_psycopg2 and all(is_psycopg2):
-                is_format = False
-        return is_bin_op or is_format
+        # check execute("...".format(self._table, table=self._table))
+        # ignore sql.SQL().format
+        if isinstance(node, astroid.Call) \
+                and isinstance(node.func, astroid.Attribute) \
+                and node.func.attrname == 'format':
+
+            if not all(map(self._sqli_allowable, node.args or [])):
+                return True
+
+            if not all(
+                self._sqli_allowable(keyword.value)
+                for keyword in (node.keywords or [])
+            ):
+                return True
+
+        return False
+
+    def _check_sql_injection_risky(self, node):
+        # Inspired from OCA/pylint-odoo project
+        # Thanks @moylop260 (Moises Lopez) & @nilshamerlinck (Nils Hamerlinck)
+        current_file_bname = os.path.basename(self.linter.current_file)
+        if not (
+            # .execute() or .executemany()
+            isinstance(node, astroid.Call) and node.args and
+            isinstance(node.func, astroid.Attribute) and
+            node.func.attrname in ('execute', 'executemany') and
+            # cursor expr (see above)
+            self.get_cursor_name(node.func) in DFTL_CURSOR_EXPR and
+            # cr.execute("select * from %s" % foo, [bar]) -> probably a good reason
+            # for string formatting
+            len(node.args) <= 1 and
+            # ignore in test files, probably not accessible
+            not current_file_bname.startswith('test_')
+        ):
+            return False
+        first_arg = node.args[0]
+        is_concatenation = self._check_node_for_sqli_risk(first_arg)
+        # if first parameter is a variable, check how it was built instead
+        if not is_concatenation:
+            for node_assignation in self._get_assignation_nodes(first_arg):
+                is_concatenation = self._check_node_for_sqli_risk(node_assignation)
+                if is_concatenation:
+                    break
+        return is_concatenation
 
     def _get_assignation_nodes(self, node):
         if isinstance(node, (astroid.Name, astroid.Subscript)):
@@ -498,7 +556,7 @@ class NoModuleChecker(misc.PylintOdooChecker):
                           'translation-required',
                           'translation-contains-variable',
                           'print-used', 'translation-positional-used',
-                          'str-format-used',
+                          'str-format-used', 'context-overridden',
                           )
     def visit_call(self, node):
         infer_node = utils.safe_infer(node.func)
@@ -515,10 +573,11 @@ class NoModuleChecker(misc.PylintOdooChecker):
                     isinstance(node.parent.targets[0], astroid.AssignName)):
                 field_name = (node.parent.targets[0].name
                               .replace('_', ' '))
+            is_related = bool([1 for kw in node.keywords or [] if kw.arg == 'related'])
             for argument in args:
                 argument_aux = argument
                 # Check this 'name = fields.Char("name")'
-                if (isinstance(argument, astroid.Const) and
+                if (not is_related and isinstance(argument, astroid.Const) and
                     (index ==
                      FIELDS_METHOD.get(argument.parent.func.attrname, 0)) and
                     (argument.value in
@@ -536,7 +595,7 @@ class NoModuleChecker(misc.PylintOdooChecker):
                                          node=argument_aux)
                     # Check if the param string is equal to the name
                     #   of variable
-                    elif argument.arg == 'string' and \
+                    elif not is_related and argument.arg == 'string' and \
                         (isinstance(argument_aux, astroid.Const) and
                          argument_aux.value in
                          [field_name.capitalize(), field_name.title()]):
@@ -559,8 +618,19 @@ class NoModuleChecker(misc.PylintOdooChecker):
                 self.get_cursor_name(node.func) in self.config.cursor_expr:
             self.add_message('invalid-commit', node=node)
 
-        # Call the message_post()
         if (isinstance(node, astroid.Call) and
+                isinstance(node.func, astroid.Attribute) and
+                node.func.attrname == 'with_context' and
+                not node.keywords and node.args):
+            # with_context(**ctx) is considered a keywords
+            # So, if only one args is received it is overridden
+            self.add_message('context-overridden', node=node,
+                             args=(node.args[0].as_string(),))
+
+        # Call the message_post()
+        base_dirname = os.path.basename(os.path.normpath(
+            os.path.dirname(self.linter.current_file)))
+        if (base_dirname != 'tests' and isinstance(node, astroid.Call) and
                 isinstance(node.func, astroid.Attribute) and
                 node.func.attrname == 'message_post'):
             for arg in itertools.chain(node.args, node.keywords or []):
@@ -645,22 +715,8 @@ class NoModuleChecker(misc.PylintOdooChecker):
                                  node=node, args=(str2translate,))
 
         # SQL Injection
-        if isinstance(node, astroid.Call) and node.args and \
-                isinstance(node.func, astroid.Attribute) and \
-                node.func.attrname in ('execute', 'executemany') and \
-                self.get_cursor_name(node.func) in self.config.cursor_expr:
-
-            first_arg = node.args[0]
-
-            risky = self._check_node_for_sqli_risk(first_arg)
-            if not risky:
-                for node_assignation in self._get_assignation_nodes(first_arg):
-                    risky = self._check_node_for_sqli_risk(node_assignation)
-                    if risky:
-                        break
-
-            if risky:
-                self.add_message('sql-injection', node=node)
+        if self._check_sql_injection_risky(node):
+            self.add_message('sql-injection', node=node)
 
     @utils.check_messages(
         'license-allowed', 'manifest-author-string', 'manifest-deprecated-key',
@@ -840,7 +896,9 @@ class NoModuleChecker(misc.PylintOdooChecker):
     @utils.check_messages('attribute-deprecated')
     def visit_assign(self, node):
         node_left = node.targets[0]
-        if isinstance(node_left, astroid.AssignName):
+        if (isinstance(node.parent, astroid.ClassDef) and
+                isinstance(node_left, astroid.AssignName) and
+                [1 for m in node.parent.basenames if 'Model' in m]):
             if node_left.name in self.config.attribute_deprecated:
                 self.add_message('attribute-deprecated',
                                  node=node_left, args=(node_left.name,))
