@@ -22,6 +22,15 @@ try:
 except ImportError:
     from whichcraft import which
 
+try:
+    import isort.api
+
+    HAS_ISORT_5 = True
+except ImportError:  # isort < 5
+    import isort
+
+    HAS_ISORT_5 = False
+
 DFTL_VALID_ODOO_VERSIONS = [
     '4.2', '5.0', '6.0', '6.1', '7.0', '8.0', '9.0', '10.0', '11.0', '12.0',
     '13.0', '14.0',
@@ -108,9 +117,10 @@ class PylintOdooChecker(BaseChecker):
             'valid_odoo_versions'].config.valid_odoo_versions
         valid_odoo_versions = '|'.join(
             map(re.escape, valid_odoo_versions))
+        manifest_version_format = self.linter._all_options[
+            'manifest_version_format'].config.manifest_version_format
         self.config.manifest_version_format_parsed = (
-            DFTL_MANIFEST_VERSION_FORMAT.format(
-                valid_odoo_versions=valid_odoo_versions))
+            manifest_version_format.format(valid_odoo_versions=valid_odoo_versions))
         return re.match(self.config.manifest_version_format_parsed, string)
 
     def get_manifest_file(self, node):
@@ -483,7 +493,7 @@ class WrapperModuleChecker(PylintOdooChecker):
                 unique_items.add(item)
         return list(duplicated_items)
 
-    def parse_xml(self, xml_file):
+    def parse_xml(self, xml_file, raise_if_error=False):
         """Get xml parsed.
         :param xml_file: Path of file xml
         :return: Doc parsed (lxml.etree object)
@@ -495,7 +505,9 @@ class WrapperModuleChecker(PylintOdooChecker):
             with open(xml_file, "rb") as f_obj:
                 doc = etree.parse(f_obj)
         except etree.XMLSyntaxError as xmlsyntax_error_exception:
-            return str(xmlsyntax_error_exception)
+            if raise_if_error:
+                raise xmlsyntax_error_exception
+            return etree.Element("__empty__")
         return doc
 
     def get_xml_records(self, xml_file, model=None, more=None):
@@ -521,8 +533,7 @@ class WrapperModuleChecker(PylintOdooChecker):
             more_filter = more
         doc = self.parse_xml(xml_file)
         return doc.xpath("/openerp//record" + model_filter + more_filter) + \
-            doc.xpath("/odoo//record" + model_filter + more_filter) \
-            if not isinstance(doc, string_types) else []
+            doc.xpath("/odoo//record" + model_filter + more_filter)
 
     def get_field_csv(self, csv_file, field='id'):
         """Get xml ids from csv file
@@ -660,3 +671,23 @@ class WrapperModuleChecker(PylintOdooChecker):
             # with the args and kwargs of the original string
             # so it is a real error
             raise StringParseError(repr(exc))
+
+
+class IsortDriver:
+    """
+    A wrapper around isort API that changed between versions 4 and 5.
+    Taken of https://git.io/Jt3dw
+    """
+
+    def __init__(self):
+        if HAS_ISORT_5:
+            self.isort5_config = isort.api.Config()
+        else:
+            self.isort4_obj = isort.SortImports(  # pylint: disable=no-member
+                file_contents=""
+            )
+
+    def place_module(self, package):
+        if HAS_ISORT_5:
+            return isort.api.place_module(package, self.isort5_config)
+        return self.isort4_obj.place_module(package)
