@@ -19,10 +19,12 @@ EXPECTED_ERRORS = {
     'attribute-deprecated': 3,
     'class-camelcase': 1,
     'consider-merging-classes-inherited': 2,
+    'context-overridden': 3,
     'copy-wo-api-one': 2,
     'create-user-wo-reset-password': 1,
     'dangerous-filter-wo-user': 1,
     'dangerous-view-replace-wo-priority': 6,
+    'dangerous-qweb-replace-wo-priority': 2,
     'deprecated-openerp-xml-node': 5,
     'development-status-allowed': 1,
     'duplicate-id-csv': 2,
@@ -56,7 +58,7 @@ EXPECTED_ERRORS = {
     'print-used': 1,
     'redundant-modulename-xml': 1,
     'rst-syntax-error': 2,
-    'sql-injection': 18,
+    'sql-injection': 21,
     'str-format-used': 3,
     'translation-field': 2,
     'translation-required': 15,
@@ -254,6 +256,31 @@ class MainTest(unittest.TestCase):
         self.expected_errors.pop('javascript-lint')
         self.assertEqual(self.expected_errors, real_errors)
 
+    def test_85_valid_odoo_version_format(self):
+        """Test --manifest_version_format parameter"""
+        # First, run Pylint for version 8.0
+        extra_params = [
+            '--manifest_version_format="8\.0\.\d+\.\d+.\d+$"'
+            '--valid_odoo_versions=""',
+            '--disable=all',
+            '--enable=manifest-version-format',
+        ]
+        pylint_res = self.run_pylint(self.paths_modules, extra_params)
+        real_errors = pylint_res.linter.stats['by_msg']
+        expected_errors = {
+            'manifest-version-format': 6,
+        }
+        self.assertDictEqual(real_errors, expected_errors)
+
+        # Now for version 11.0
+        extra_params[0] = '--manifest_version_format="11\.0\.\d+\.\d+.\d+$"'
+        pylint_res = self.run_pylint(self.paths_modules, extra_params)
+        real_errors = pylint_res.linter.stats['by_msg']
+        expected_errors = {
+            'manifest-version-format': 5,
+        }
+        self.assertDictEqual(real_errors, expected_errors)
+
     def test_90_valid_odoo_versions(self):
         """Test --valid_odoo_versions parameter when it's '8.0' & '11.0'"""
         # First, run Pylint for version 8.0
@@ -358,6 +385,35 @@ class MainTest(unittest.TestCase):
             {"po-msgstr-variables": 1, "missing-readme": 1}
         )
 
+    def test_140_check_suppress_migrations(self):
+        """Test migrations path supress checks"""
+        extra_params = [
+            '--disable=all',
+            '--enable=invalid-name,unused-argument',
+        ]
+        path_modules = [os.path.join(
+            os.path.dirname(os.path.dirname(os.path.realpath(__file__))),
+            'test_repo', 'test_module', 'migrations', '10.0.1.0.0', 'pre-migration.py')]
+
+        # Messages suppressed with plugin for migration
+        pylint_res = self.run_pylint(path_modules, extra_params)
+        real_errors = pylint_res.linter.stats['by_msg']
+        expected_errors = {
+            'invalid-name': 1,
+            'unused-argument': 1,
+        }
+        self.assertDictEqual(real_errors, expected_errors)
+
+        # Messages raised without plugin
+        self.default_options.remove('--load-plugins=pylint_odoo')
+        pylint_res = self.run_pylint(path_modules, extra_params)
+        real_errors = pylint_res.linter.stats['by_msg']
+        expected_errors = {
+            'invalid-name': 3,
+            'unused-argument': 2,
+        }
+        self.assertDictEqual(real_errors, expected_errors)
+
 
 if __name__ == '__main__':
     unittest.main()
